aboutsummaryrefslogtreecommitdiff
path: root/mesalib/src/mapi/glapi/gen
diff options
context:
space:
mode:
authormarha <marha@users.sourceforge.net>2012-12-17 11:51:13 +0100
committermarha <marha@users.sourceforge.net>2012-12-17 11:51:13 +0100
commit840c8745518b92303d40f6834e9c616587242231 (patch)
tree097a30453fb59b6a88708c3f576e824e8f237c52 /mesalib/src/mapi/glapi/gen
parentb395c3c85251d4e8761704d8e3a3c9f9fa5b45cc (diff)
downloadvcxsrv-840c8745518b92303d40f6834e9c616587242231.tar.gz
vcxsrv-840c8745518b92303d40f6834e9c616587242231.tar.bz2
vcxsrv-840c8745518b92303d40f6834e9c616587242231.zip
libXft pixman mesa git update 17 dec 2012
libXft: 835cd2a6cb4aa8f89e6e7dead66483643a6e7ee8 pixman: 526dc06e5694172abf979c03a5cf530207fe2d27 mesa: 1358f3a905448f6fb546aba951e317f743a83c76
Diffstat (limited to 'mesalib/src/mapi/glapi/gen')
-rw-r--r--mesalib/src/mapi/glapi/gen/gl_genexec.py21
1 files changed, 9 insertions, 12 deletions
diff --git a/mesalib/src/mapi/glapi/gen/gl_genexec.py b/mesalib/src/mapi/glapi/gen/gl_genexec.py
index 593d1955b..da9ae716a 100644
--- a/mesalib/src/mapi/glapi/gen/gl_genexec.py
+++ b/mesalib/src/mapi/glapi/gen/gl_genexec.py
@@ -22,7 +22,7 @@
# IN THE SOFTWARE.
# This script generates the file api_exec.c, which contains
# _mesa_create_exec_table(). It is responsible for populating all
# entries in the "exec" dispatch table that aren't dynamic.
import collections
@@ -112,29 +112,26 @@ header = """/**
/**
- * Initialize a dispatch table with pointers to Mesa's immediate-mode
- * commands.
+ * Initialize a context's exec table with pointers to Mesa's supported
+ * GL functions.
*
- * Pointers to glBegin()/glEnd() object commands and a few others
- * are provided via the GLvertexformat interface.
+ * This function depends on ctx->Version.
*
* \param ctx GL context to which \c exec belongs.
- * \param exec dispatch table.
*/
-struct _glapi_table *
-_mesa_create_exec_table(struct gl_context *ctx)
+void
+_mesa_initialize_exec_table(struct gl_context *ctx)
{
struct _glapi_table *exec;
- exec = _mesa_alloc_dispatch_table(_gloffset_COUNT);
- if (exec == NULL)
- return NULL;
+ exec = ctx->Exec;
+ assert(exec != NULL);
+ assert(ctx->Version > 0);
"""
footer = """
- return exec;
}
"""
@@ -22,7 +22,7 @@
# IN THE SOFTWARE.
# This script generates the file api_exec.c, which contains
-# _mesa_create_exec_table(). It is responsible for populating all
+# _mesa_initialize_exec_table(). It is responsible for populating all
# entries in the "exec" dispatch table that aren't dynamic.
import collections